<?php include_once('functions.php'); ?>
<html>
  <head>
    <title>Honeypot Test</title>
  </head>
  <body>
    <style>
      .formfield {
        width:100%;
        margin-bottom:20px;
      }

      .noeyes {
        display:none;
      }

    </style>
    <form action="contact.php" method="POST">
      <!-- # Felder die durch User ausgefüllt werden -->
      <div class="formfield">
        <label for="name">Name:</label>
        <input type="text" name="name">
      </div>
      <div class="formfield">
        <label for="email">E-Mail:</label>
        <input type="email" name="email">
      </div>
      <div class="formfield">
        <label for="message">Ihre Nachricht</label>
        <textarea name="message"></textarea>
      </div>


      <!-- Sicherheitsfelder
        Im Nonce Feld wird ein zuvor erstellter "Fingerabdruck" abgespeichert
        der später im Actions Controller geprüft wird. Die Nonce auch CSRF oder
        anders genannt wird benötigt um Cross Scripting Angriffe zu erschweren.
        CMS Systeme wie WordPress oder Frameworks wie Laravel haben passende Funktionen
        zur Einbindung dieser Felder sowie zur Überprüfung. In diesem Beispielt dient das Feld
        nur um euch darauf aufmerksam zu machen diese Funktionen unbedingt zu verwenden.
      -->
        <input type="hidden" name="nonce" value="publicsecret1">


      <!-- Honeypot Feld
        Spam Bots suchen in Formularfeldern nach bekannten Bezeichnungen um einzelne Felder
        voneinander unterscheiden zu können. So gut wie jeder Bot kann dabei zwischen
        den verschiedenen Arten an Textfeldern unterscheiden. Ist ein Textfeld als hidden
        markiert werden sie von Bots ignoriert. Aus diesem Grund erhält unser Honeypot Feld
        per CSS den Wert "display:none;". Dies verhindert das der Browser dem Besucher das Feld
        anzeigt, einfache Bots gehen davon aus, dass das Feld sichtbar ist. Zusätzlich erhält
        das Feld den ansprechenden Namen "subject". Sollte unser "subject" Feld bei der späteren
        Prüfung ausgefüllt sein, können wir die Anfrage direkt blockieren.

        Nachtrag: Ausgefeiltere Bots können über CSS ausgeblendete Elemente erkennen und
        uns nicht in die Falle gehen.
      -->
      <input type="text" class="noeyes" name="subject" value="">


      <!-- Timer Feld
        Für Spammer ist Zeit Geld. Ein Bot hält sich auf jeder Seite also nicht lange
        auf bevor er zur nächsten Seite weiterspringt. Die benötigten Informationen
        werden abgerufen und sofern sich ein Kontaktformular oder ein anderes Ziel
        auf einer Seite befindet, wird dieses angegriffen.
        Die Zeit die ein Bot benötigt um ein Formular auszufüllen liegt oft unter einer Sekunde.
        Diesen Umstand können wir zu unserem Vorteil nutzen. Im Timer Feld platzieren wir
        einen kodierten Timestamp der bei der Abfrage der Seite generiert wird.
        Während der Validierung des Formulars prüfen wir den Timer um zu sehen wie schnell das
        Formular ausgefüllt und abgeschickt wurde. Formulare die in weniger als 5 Sekunden
        ausgefüllt und abgeschickt wurden können wir anschließend mit ziemlicher Sicherheit blockieren.

      -->
      <input type="text" class="noeyes" name="phone" value="<?php echo generateTimeHash($key, $cipher, $iv); ?>">

      <input type="submit" value="Absenden">

    </form>
  </body>
</html>
